/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : InterruptExample.c
* Author             : MCD Application Team
* Version            : 1.0
* Date               : 08/21/2007
* Description        : This file gives an example of using the ST10F27x CAN library 
*                      functions in Interrupt mode 
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include <REG276.H>
#include "ST10F27x_can.h"
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define CAN_TX_MSGOBJ  0 
#define CAN_RX_MSGOBJ  1  
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
canmsg RxCanMsg;
canmsg CanMsg;

/* Message Array */  
canmsg TxCanMsg[3] = {
	{ CAN_STD_ID, 0x3B1, 4, { 0x01, 0x02, 0x04, 0x08 } },
   	{ CAN_STD_ID, 0x3B2, 8, { 0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17 } },
	{ CAN_STD_ID, 0x372, 4, { 0xAA, 0x55, 0xAA, 0x55 } }
  };

/* Private function prototypes -----------------------------------------------*/
void CAN_Interrupt_Config( void );
void CAN_Com_Interrupt( void );

/* Private functions----------------------------------------------------------*/

/*******************************************************************************
* Function Name  : main
* Description    : Main program
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void main(void)
{
   /* Port pins configuration */
    /* P4.6 -> CAN1 Tx, P4.7 -> CAN2 Tx */
	/* P4.4 and P4.5 -> CAN Rx */
	DP4 |= 0xC0;
	_nop();
	P4 |= 0xC0;	
   CAN_Interrupt_Config();

   CAN_Com_Interrupt(); 
    
	while(1);
}

/*******************************************************************************
* Function Name  : CAN_Interrupt_Config                                             
* Description    : Configures the vectors XP0IC and XP1IC and enables the CAN1
*                  and CAN2 interrupts    
* Input          : None                                                       
* Output         : None                                                      
* Return         : None 
*******************************************************************************/
void CAN_Interrupt_Config( void )
{
	/* Configure the CAN1 Interrupt using XP0IC */
	 XP0IC = 0x74;
     /* Setthe XIR0SEL.8 to enable the CAN1 Interrupt */
	 XIR0SEL = 0x0100;
	/* Configure the CAN2 Interrupt using XP1IC */
	XP1IC = 0x78;
	/* Set the XIR1SEL.8 to enable the CAN2 Interrupt */
	XIR1SEL = 0x0100;
}

/*******************************************************************************
* Function Name  : CAN1_Interrupt                                              
* Description    : Treats the CAN1 Interrupt    
* Input          : None                                                       
* Output         : None                                                      
* Return         : None 
*******************************************************************************/
_interrupt (0x40 ) void CAN1_Interrupt ( void )
{
  /* Clear the XIR0SEL.0 */
  XIR0CLR = 0x0001;
  /*  retransmit the second message object*/
  CAN_SendMessage( CAN1 , CAN_TX_MSGOBJ, &TxCanMsg[1] );  
}

/*******************************************************************************
* Function Name  : CAN2_Interrupt                                              
* Description    : Treats the CAN2 Interrupt    
* Input          : None                                                       
* Output         : None                                                      
* Return         : None 
*******************************************************************************/
_interrupt (0x41 ) void CAN2_Interrupt ( void )
{
  static vu8 index = 0;

  /* Clear the XIR1SEL.0 */
  XIR1CLR = 0x0001;
  index++;
  /* Receive the message object */
  CAN_ReceiveMessage( CAN2, CAN_RX_MSGOBJ, TRUE, &RxCanMsg );        
}

/*******************************************************************************
* Function Name  : CAN_Com_Interrupt                                             
* Description    : Configures the CAN1 and CAN2 and triggers the transmission
*                  a data frame by CAN1    
* Input          : None                                                       
* Output         : None                                                      
* Return         : None 
*******************************************************************************/
void CAN_Com_Interrupt(void)
{
  /* Initialize the CAN1 and Enable CAN Interrupts*/
  CAN_Init(CAN1, CAN_CR_IE, CAN_BITRATE_500K);

  /* Initialize the CAN2 */
  CAN_Init(CAN2, CAN_CR_IE, CAN_BITRATE_500K);
  
  /*Set up the CAN_TX_MSGOBJ of CAN1 to transmit a message object with standard ID */
  CAN_SetTxMsgObj(CAN1, CAN_TX_MSGOBJ, CAN_STD_ID, DISABLE);

  /*Set up the CAN_RX_MSGOBJ of CAN2 to Receive the message object which ID = 0x011101100xx */
  CAN_SetRxMsgObj(CAN2, CAN_RX_MSGOBJ, CAN_STD_ID, 0x3B0, 0x3B3, TRUE);

  /* Send the first pre-defined answer */
  CAN_SendMessage(CAN1, CAN_TX_MSGOBJ, &TxCanMsg[0]);
}

/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/


