/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : PollingExample.c
* Author             : MCD Application Team
* Version            : 1.0 
* Date               : 08/21/2007
* Description        : This file gives an example of using the ST10F27x CAN library 
*                      functions in polling mode 
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Inlcudes ------------------------------------------------------------------*/
#include <REG276.H>
#include <stdio.h>
#include "ST10F27x_can.h"
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
#define CAN_TX_MSGOBJ  0 
#define CAN_RX_MSGOBJ  1  
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
canmsg RxCanMsg;
canmsg CanMsg;

/* Message Array */  
canmsg TxCanMsg[3] = {
	{ CAN_STD_ID, 0x3B1, 4, { 0x01, 0x02, 0x04, 0x08 } },
   	{ CAN_STD_ID, 0x0B0, 8, { 0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17 } },
	{ CAN_STD_ID, 0x3B2, 4, { 0xAA, 0x55, 0xAA, 0x55 } }
  };

/* Private function prototypes -----------------------------------------------*/
void CAN_Com_Polling(void);

/*******************************************************************************
* Function Name  : main
* Description    : Main program
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void main(void)
{  
   /* Port pins configuration */
    /* P4.6 -> CAN1 Tx, P4.7 -> CAN2 Tx */
	/* P4.4 and P4.5 -> CAN Rx */
	DP4 |= 0xC0;
	_nop();
	P4 |= 0xC0;	

   CAN_Com_Polling(); 
    
	while(1);
}

/*******************************************************************************
* Function Name  : CAN_Com_Polling                                            
* Description    : This functions configures the CAN1 to transmit two message
*                  objects with different IDs to the CAN2 cell.  
* Input          : None                                                      
* Output         : None                                                      
* Return         : None 
*******************************************************************************/
void CAN_Com_Polling(void)
{
   /* Initialize the CAN1 */
  CAN_Init(CAN1, 0, CAN_BITRATE_500K);

  /* Initialize the CAN2 */
  CAN_Init(CAN2, 0, CAN_BITRATE_500K);
  
  /*Set up the CAN_TX_MSGOBJ of CAN1 to transmit a message object with standard ID */
  CAN_SetTxMsgObj(CAN1, CAN_TX_MSGOBJ, CAN_STD_ID, DISABLE);

  /*Set up the CAN_RX_MSGOBJ of CAN2 to Receive the message object which ID = 0x011101100xx */
  CAN_SetRxMsgObj(CAN2, CAN_RX_MSGOBJ, CAN_STD_ID, 0x3B0, 0x3B3, TRUE);

  /* Send the first pre-defined answer */
  CAN_SendMessage(CAN1, CAN_TX_MSGOBJ, &TxCanMsg[0]);

  T3R = 1;

  /* wait for reception of a data frame */
  while (!CAN_ReceiveMessage(CAN2, CAN_RX_MSGOBJ, TRUE, &RxCanMsg) && !T3IR);
  if(T3IR) printf( "No message received: TIMEOUT\n");
  else printf( "Message Received with ID=0x%x\n", RxCanMsg.Id);
  T3R = 0;
  T3IR = 0;
  T3 = 0;

  /* Send the second-message object */
  CAN_SendMessage(CAN1, CAN_TX_MSGOBJ, &TxCanMsg[1]);

  T3R = 1;
  while (!CAN_ReceiveMessage(CAN2, CAN_RX_MSGOBJ, TRUE, &RxCanMsg) && !T3IR);
  if(T3IR) printf( "No message received: TIMEOUT\n");
  else printf( "Message Received with ID = %x\n", RxCanMsg.Id);
  T3R = 0;

  /* release the message objects */
  CAN_ReleaseMessage(CAN1, CAN_TX_MSGOBJ);
  CAN_ReleaseMessage(CAN2, CAN_RX_MSGOBJ); 
}

/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/


