/******************** (C) COPYRIGHT 2007 STMicroelectronics ********************
* File Name          : ST10F27x_can.h
* Author             : MCD Application Team
* Version            : 1.0
* Date               : 08/21/2007  
* Description        : This file contains all the functions prototypes for the
*                      CAN bus software library.
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __ST10F27x_CAN_H
#define __ST10F27x_CAN_H

/* Includes ------------------------------------------------------------------*/
#include "st10f27x_types.h"

/* Exported types ------------------------------------------------------------*/
/* CAN Interface IFx registers mapping and defintions */
typedef volatile struct
  {
    vu16 CRR;			
    vu16 CMR;			
    vu16 M1R;			
    vu16 M2R;			
    vu16 A1R;			
    vu16 A2R;			
    vu16 MCR;			
    vu16 DA1R;		
    vu16 DA2R;		
    vu16 DB1R;		
    vu16 DB2R;		
    u16  EMPTY0[13];
} CAN_MsgObj_TypeDef;

/* C-CAN Block registers and mapping definition */
typedef volatile struct
{
  vu16 CR;			
  vu16 SR;			
  vu16 ERR;			
  vu16 BTR;			
  vu16 IDR;			
  vu16 TESTR;		
  vu16 BRPR;		
  u16  EMPTY0;
  CAN_MsgObj_TypeDef sMsgObj[2];
  u16  EMPTY1[8];
  vu16 TXR1R;		
  vu16 TXR2R;		
  u16  EMPTY2[6];
  vu16 ND1R;		
  vu16 ND2R;		
  u16  EMPTY3[6];
  vu16 IP1R;		
  vu16 IP2R;		
  u16  EMPTY4[6];
  vu16 MV1R;		
  vu16 MV2R;		
} CAN_TypeDef;

/* Exported constants --------------------------------------------------------*/
/* Standard bitrates available*/
enum
{
  CAN_BITRATE_100K,
  CAN_BITRATE_125K,
  CAN_BITRATE_250K,
  CAN_BITRATE_500K,
  CAN_BITRATE_1M
};

/* C-CAN modules defintion */
#define CAN1_BASE              0xEF00
#define CAN2_BASE              0xEE00
#define CAN1         ( (CAN_TypeDef *)   CAN1_BASE)
#define CAN2         ( (CAN_TypeDef *)   CAN2_BASE)         

/* C-CAN Control register bits definition */
#define CAN_CR_TEST            0x0080
#define CAN_CR_CCE             0x0040
#define CAN_CR_DAR             0x0020
#define CAN_CR_EIE             0x0008
#define CAN_CR_SIE             0x0004
#define CAN_CR_IE              0x0002
#define CAN_CR_INIT            0x0001

/*C-CAN  Status register bits definition*/
#define CAN_SR_BOFF            0x0080
#define CAN_SR_EWARN           0x0040
#define CAN_SR_EPASS           0x0020
#define CAN_SR_RXOK            0x0010
#define CAN_SR_TXOK            0x0008
#define CAN_SR_LEC             0x0007

/* C-CAN Test register bits definition */
#define CAN_TESTR_RX           0x0080
#define CAN_TESTR_TX1          0x0040
#define CAN_TESTR_TX0          0x0020
#define CAN_TESTR_LBACK        0x0010
#define CAN_TESTR_SILENT       0x0008
#define CAN_TESTR_BASIC        0x0004

/* IFn / Command Request register */
#define CAN_CRR_BUSY           0x8000

/* IFn / Command Mask register bits definition */
#define CAN_CMR_WRRD           0x0080
#define CAN_CMR_MASK           0x0040
#define CAN_CMR_ARB            0x0020
#define CAN_CMR_CONTROL        0x0010
#define CAN_CMR_CLRINTPND      0x0008
#define CAN_CMR_TXRQSTNEWDAT   0x0004
#define CAN_CMR_DATAA          0x0002
#define CAN_CMR_DATAB          0x0001

/* IFn / Mask 2 register bits definition */
#define CAN_M2R_MXTD           0x8000
#define CAN_M2R_MDIR           0x4000

/* IFn / Arbitration 2 register bits definition */
#define CAN_A2R_MSGVAL         0x8000
#define CAN_A2R_XTD            0x4000
#define CAN_A2R_DIR            0x2000

/* IFn / Message Control register bits definition */
#define CAN_MCR_NEWDAT         0x8000
#define CAN_MCR_MSGLST         0x4000
#define CAN_MCR_INTPND         0x2000
#define CAN_MCR_UMASK          0x1000
#define CAN_MCR_TXIE           0x0800
#define CAN_MCR_RXIE           0x0400
#define CAN_MCR_RMTEN          0x0200
#define CAN_MCR_TXRQST         0x0100
#define CAN_MCR_EOB            0x0080

/* CAN message structure definition */
typedef struct
{
  u16 IdType;
  u32 Id;
  u8 Dlc;
  u8 Data[8];
} canmsg;

/* Message ID types */
enum
{
  CAN_STD_ID,
  CAN_EXT_ID
};

/* Message ID limits */
#define CAN_LAST_STD_ID	((1<<11) - 1)
#define CAN_LAST_EXT_ID	((1L<<29) - 1)

/* Exported functions ------------------------------------------------------- */
void CAN_EnterInitMode(CAN_TypeDef *CAN, u16 Mask);
void CAN_LeaveInitMode(CAN_TypeDef *CAN);
void CAN_EnterTestMode(CAN_TypeDef *CAN, u16 TestMask);
void CAN_LeaveTestMode(CAN_TypeDef *CAN);
void CAN_SetBitrate(CAN_TypeDef *CAN, u16 bitrate);
void CAN_SetTiming(CAN_TypeDef *CAN, u16 tseg1, u16 tseg2, u16 sjw, u16 brp);
void CAN_Init(CAN_TypeDef *CAN , u16 Mask, u16 Bitrate);
ErrorStatus CAN_SetUnusedMsgObj(CAN_TypeDef *CAN, u16 msgobj);
ErrorStatus CAN_SetUnusedAllMsgObj(CAN_TypeDef *CAN);
ErrorStatus CAN_ReleaseMessage(CAN_TypeDef *CAN, u16 msgobj);
ErrorStatus CAN_SetTxMsgObj(CAN_TypeDef *CAN, u16 msgobj, u16 idType, FunctionalState RemoteEN);
ErrorStatus CAN_SetRxMsgObj(CAN_TypeDef *CAN, u16 msgobj, u16 idType, u32 idLow, u32 idHigh, 
                             bool singleOrFifoLast); 
ErrorStatus CAN_UpdateMsgObj( CAN_TypeDef* CAN, u16 msgobj, canmsg* pCanMsg);
ErrorStatus CAN_TransmitRequest( CAN_TypeDef *CAN, u16 msgobj );
ErrorStatus CAN_SendMessage(CAN_TypeDef *CAN, u16 msgobj, canmsg* pCanMsg);
ErrorStatus CAN_ReceiveMessage(CAN_TypeDef *CAN, u16 msgobj, bool release, canmsg* pCanMsg);
ErrorStatus CAN_BasicSendMessage(CAN_TypeDef *CAN, canmsg* pCanMsg);
ErrorStatus CAN_BasicReceiveMessage(CAN_TypeDef *CAN, canmsg* pCanMsg);
void CAN_WaitEndOfTx( CAN_TypeDef* CAN );
FlagStatus CAN_GetMsgReceiveStatus(CAN_TypeDef *CAN, u16 msgobj);
FlagStatus CAN_GetMsgTransmitRequestStatus(CAN_TypeDef *CAN, u16 msgobj);
FlagStatus CAN_GetMsgInterruptStatus(CAN_TypeDef *CAN, u16 msgobj);
FlagStatus CAN_GetMsgValidStatus(CAN_TypeDef *CAN, u16 msgobj);
FlagStatus CAN_GetFlagStatus ( CAN_TypeDef *CAN, u16 CAN_Flag );
u8 CAN_GetTransmitErrorCounter ( CAN_TypeDef *CAN );
u8 CAN_GetReceiveErrorCounter ( CAN_TypeDef *CAN);

#endif /* __ST10F27x_CAN_H */

/******************* (C) COPYRIGHT 2007 STMicroelectronics *****END OF FILE****/

